@@ -182,6 +182,7 @@ check_acl_ask_request (GkrAskRequest* ask, GnomeKeyringApplicationRef *app)
 		return GKR_ASK_STOP_REQUEST;
 	}
 	
+#ifdef ENABLE_ACL_PROMPTS
 	/* Did prompting already occur? */
 	if (ask->response) {
 		
@@ -197,6 +198,10 @@ check_acl_ask_request (GkrAskRequest* ask, GnomeKeyringApplicationRef *app)
 	
 	/* Continue with prompting */
 	return GKR_ASK_DONT_CARE;
+#else /* !ENABLE_ACL_PROMPTS */
+	ask->response = GKR_ASK_RESPONSE_ALLOW;
+	return GKR_ASK_STOP_REQUEST;
+#endif /* ENABLE_ACL_PROMPTS */
 }
 
 static gboolean
@@ -281,72 +286,6 @@ request_item_access (GkrKeyringRequest *req, GkrKeyringItem *item,
 	return ret;
 }
 
-static gboolean 
-check_keyring_ask_request (GkrAskRequest* ask)
-{
-	GkrKeyring *keyring;
-	const gchar *password;
-	gchar *display;
-	
-	keyring = GKR_KEYRING (gkr_ask_request_get_object (ask));
-	g_assert (GKR_IS_KEYRING (keyring));
-
-	if (!keyring->locked) {
-		ask->response = GKR_ASK_RESPONSE_ALLOW;
-		return GKR_ASK_STOP_REQUEST;
-	}
-	
-	/* If they typed a password, try it out */
-	if (ask->response >= GKR_ASK_RESPONSE_ALLOW) {
-		
-		g_assert (ask->typed_password);
-		if (!gkr_keyring_unlock (keyring, ask->typed_password)) {
-			/* Bad password, try again */
-			ask->response = GKR_ASK_RESPONSE_NONE;
-			return GKR_ASK_CONTINUE_REQUEST;
-		}
-		
-		/* Did they ask us to remember the password? */
-		if (ask->checked) {
-			display = g_strdup_printf (_("Unlock password for %s keyring"), 
-			                           keyring->keyring_name);
-			gkr_keyring_login_attach_secret (GNOME_KEYRING_ITEM_CHAINED_KEYRING_PASSWORD,
-			                                 display, ask->typed_password, 
-			                                 "keyring", gkr_location_to_string (keyring->location), NULL);
-			g_free (display);
-		}
-	}
-	
-	/* 
-	 * We can automatically unlock keyrings that have their password
-	 * stored in the 'login' keyring.
-	 */
-	password = gkr_keyring_login_lookup_secret (GNOME_KEYRING_ITEM_CHAINED_KEYRING_PASSWORD,
-	                                            "keyring", gkr_location_to_string (keyring->location), NULL);
-	if (password) {
-		if (gkr_keyring_unlock (keyring, password)) {
-			
-			/* A good password, unlocked, all done */
-			ask->response = GKR_ASK_RESPONSE_ALLOW;
-			return GKR_ASK_STOP_REQUEST;
-			
-		} else {
-			
-			/* A bad internal password */
-			gkr_keyring_login_remove_secret (GNOME_KEYRING_ITEM_CHAINED_KEYRING_PASSWORD,
-			                                 "keyring", gkr_location_to_string (keyring->location), NULL);
-		}
-	}	
-
-	/* If the keyring is unlocked then no need to continue */
-	if (!keyring->locked) {
-		ask->response = GKR_ASK_RESPONSE_ALLOW;
-		return GKR_ASK_STOP_REQUEST;
-	}
-	
-	return GKR_ASK_DONT_CARE;
-}
-
 static gboolean
 request_keyring_access (GkrKeyringRequest *req, GkrKeyring *keyring)
 {
@@ -428,7 +367,7 @@ request_keyring_access (GkrKeyringRequest *req, GkrKeyring *keyring)
 		gkr_ask_request_set_check_option (ask, _("Automatically unlock this keyring when I log in."));
 	
 	/* Intercept item access requests to see if we still need to prompt */
-	g_signal_connect (ask, "check-request", G_CALLBACK (check_keyring_ask_request), NULL);
+	g_signal_connect (ask, "check-request", G_CALLBACK (gkr_keyring_ask_check_unlock), NULL);
 	
 	g_free (primary);
 	g_free (message);
@@ -588,7 +527,7 @@ request_change_keyring_password (GkrKeyringRequest *req, GkrKeyring* keyring,
 		} 
 	}
 	
-	flags = GKR_ASK_REQUEST_NEW_PASSWORD;
+	flags = GKR_ASK_REQUEST_CHANGE_PASSWORD;
 	if (!*original)
 		flags |= GKR_ASK_REQUEST_ORIGINAL_PASSWORD;
 
@@ -649,6 +588,9 @@ check_keyring_default_request (GkrAskRequest* ask)
 
 			/* Set our newly created keyring as the default */
 			gkr_keyrings_set_default (keyring);
+			
+			/* Let go of the initial reference to this object */
+			g_object_unref (keyring);
 		}
 	}
 	
@@ -1191,8 +1133,7 @@ op_create_item (GkrBuffer *packet, GkrBuffer *result,
 		return FALSE;
 	}
 
-	if ((type & GNOME_KEYRING_ITEM_TYPE_MASK) >= GNOME_KEYRING_ITEM_LAST_TYPE ||
-	    display_name == NULL || secret == NULL) {
+	if (display_name == NULL || secret == NULL) {
 		res = GNOME_KEYRING_RESULT_BAD_ARGUMENTS;
 		goto out;
 	}
@@ -1222,7 +1163,7 @@ op_create_item (GkrBuffer *packet, GkrBuffer *result,
 	}
 	
 	if (update_if_exists) {
-		item = gkr_keyring_find_item (keyring, type, keyring->locked ? hashed : attributes);
+		item = gkr_keyring_find_item (keyring, type, keyring->locked ? hashed : attributes, TRUE);
 		if (item) {
 			/* Make sure we have access to the previous item */
 			if (!request_item_access (req, item, GNOME_KEYRING_ACCESS_WRITE, TRUE))
@@ -1233,6 +1174,7 @@ op_create_item (GkrBuffer *packet, GkrBuffer *result,
 	if (!item) {
 		item = gkr_keyring_item_create (keyring, type);
 		gkr_keyring_add_item (keyring, item);
+		g_object_unref (item);
 	}
 
 	/* Copy in item type flags */
@@ -1270,6 +1212,7 @@ op_delete_item (GkrBuffer *packet, GkrBuffer *result,
                 GkrKeyringRequest *req)
 {
 	char *keyring_name;
+	GkrKeyring *keyring;
 	GkrKeyringItem *item;
 	GnomeKeyringOpCode opcode;
 	guint32 item_id;
@@ -1293,8 +1236,9 @@ op_delete_item (GkrBuffer *packet, GkrBuffer *result,
 	gkr_buffer_add_uint32 (result, res);
 	if (res == GNOME_KEYRING_RESULT_OK) {
 		if (item->keyring) {
-			gkr_keyring_remove_item (item->keyring, item);
-			gkr_keyring_save_to_disk (item->keyring);
+			keyring = item->keyring;
+			gkr_keyring_remove_item (keyring, item);
+			gkr_keyring_save_to_disk (keyring);
 		}
 	}
 
@@ -1686,7 +1630,7 @@ op_find (GkrBuffer *packet, GkrBuffer *result, GkrKeyringRequest *req)
 
 	/* Need at least one attribute to match on */
 	if (ctx.attributes->len > 0) {
-		ctx.hashed = gkr_keyring_item_attributes_hash (ctx.attributes);
+		ctx.hashed = gkr_attribute_list_hash (ctx.attributes);
 		ctx.nfound = 0;
 		ctx.req = req;
 		ctx.items = NULL;
@@ -1763,7 +1707,9 @@ op_prepare_daemon_environment (GkrBuffer *packet, GkrBuffer *result, GkrKeyringR
 			else if (g_str_equal (*e, "XAUTHORITY"))
 				g_setenv ("XAUTHORITY", x, FALSE);
 			else if (g_str_equal (*e, "XDG_SESSION_COOKIE"))
-				g_setenv ("XDG_SESSION_COOKIE", x, FALSE);
+				g_setenv ("XDG_SESSION_COOKIE", x, FALSE);	
+			else if (g_str_equal (*e, "LANG"))
+				g_setenv ("LANG", x, FALSE);
 		}
 	}
 	
