@@ -328,8 +328,6 @@ parsed_pem_block (GQuark type, const guchar *data, gsize n_data,
 	gchar *comment;
 	gkrid digest;
 	
-g_message("saw PEM block: %s", g_quark_to_string (type));
-
 	/* Only handle SSHv2 private keys */
 	if (type != PEM_RSA_PRIVATE_KEY && type != PEM_DSA_PRIVATE_KEY)
 		return;
@@ -343,7 +341,6 @@ g_message("saw PEM block: %s", g_quark_to_string (type));
 	
 	/* If it's encrypted ... */
 	dekinfo = gkr_pkix_openssl_get_dekinfo (headers);
-g_message("dekinfo: %s", dekinfo);
 	if (dekinfo) {
 		/* This key was specifically requested to be loaded */
 		if (gkr_id_equals (digest, pv->specific_load_request)) {
@@ -352,7 +349,6 @@ g_message("dekinfo: %s", dekinfo);
 			
 		/* Nobody's asking us to load this key just yet */
 		} else {
-g_message("skipping loading of wrong key");
 			ctx->result = GKR_PKIX_SUCCESS;
 			sexp = NULL;
 		}
@@ -362,7 +358,7 @@ g_message("skipping loading of wrong key");
 		ctx->result = gkr_pkix_der_read_private_key (data, n_data, &sexp);
 	}
 	
-	if (!ctx->result == GKR_PKIX_SUCCESS) {
+	if (ctx->result != GKR_PKIX_SUCCESS) {
 		gkr_id_free (digest);
 		return;
 	}
@@ -399,7 +395,6 @@ storage_load_private_key (GkrSshStorage *storage, GQuark loc, GError **err)
 	g_return_val_if_fail (loc, FALSE);
 	g_return_val_if_fail (!err || !*err, FALSE);
 	
-g_message("loading SSH private key at: %s", g_quark_to_string (loc));
 	if (!gkr_location_read_file (loc, &data, &n_data, err))
 		return FALSE;
 
@@ -632,6 +627,7 @@ gkr_ssh_storage_store (GkrPkStorage *stor, GkrPkObject *obj, GError **err)
 	
 	/* The object now has a (possibly new) location */
 	g_object_set (obj, "location", loc, "storage", stor, "digest", digest, NULL);
+	gkr_pk_storage_add_object (stor, obj);
 	gkr_id_free (digest);
 	
 	/* Now store the public key in place if possible */
